#/bin/sh
rm /usr/lib/hildon-desktop/queen-beecon.so
rm /usr/share/applications/hildon-home/queen-beecon.desktop
rm -r /var/lib/gconf/apps/osso/hildon-desktop/applets/queen-beecon.*